package sun.security.util;

import java.security.cert.CertificateException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.KeyStoreException;
import java.util.Arrays;
import java.io.BufferedInputStream;
import java.net.MalformedURLException;
import java.security.KeyStore;
import java.io.IOException;
import java.io.FileInputStream;
import sun.net.www.ParseUtil;
import java.io.File;
import java.io.InputStream;
import java.net.URL;

public class PolicyUtil
{
    private static final String P11KEYSTORE = "PKCS11";
    private static final String NONE = "NONE";
    
    public PolicyUtil() {
    }
    
    public static InputStream getInputStream(URL url) throws IOException {
        if ("file".equals(url.getProtocol())) {
            return new FileInputStream(ParseUtil.decode(url.getFile().replace('/', File.separatorChar)));
        }
        return url.openStream();
    }
    
    public static KeyStore getKeyStore(URL url, String str, String defaultType, String provider, String s, Debug debug) throws KeyStoreException, MalformedURLException, IOException, NoSuchProviderException, NoSuchAlgorithmException, CertificateException {
        if (str == null) {
            throw new IllegalArgumentException("null KeyStore name");
        }
        char[] password = null;
        try {
            if (defaultType == null) {
                defaultType = KeyStore.getDefaultType();
            }
            if ("PKCS11".equalsIgnoreCase(defaultType) && !"NONE".equals(str)) {
                throw new IllegalArgumentException("Invalid value (" + str + ") for keystore URL.  If the keystore type is \"" + "PKCS11" + "\", the keystore url must be \"" + "NONE" + "\"");
            }
            KeyStore keyStore;
            if (provider != null) {
                keyStore = KeyStore.getInstance(defaultType, provider);
            }
            else {
                keyStore = KeyStore.getInstance(defaultType);
            }
            if (s != null) {
                Object obj;
                try {
                    obj = new URL(s);
                }
                catch (MalformedURLException ex) {
                    if (url == null) {
                        throw ex;
                    }
                    obj = new URL(url, s);
                }
                if (debug != null) {
                    debug.println("reading password" + obj);
                }
                InputStream openStream = null;
                try {
                    openStream = obj.openStream();
                    password = Password.readPassword(openStream);
                }
                finally {
                    if (openStream != null) {
                        openStream.close();
                    }
                }
            }
            if ("NONE".equals(str)) {
                keyStore.load(null, password);
            }
            else {
                Object obj2;
                try {
                    obj2 = new URL(str);
                }
                catch (MalformedURLException ex2) {
                    if (url == null) {
                        throw ex2;
                    }
                    obj2 = new URL(url, str);
                }
                if (debug != null) {
                    debug.println("reading keystore" + obj2);
                }
                Object stream = null;
                try {
                    stream = new BufferedInputStream(getInputStream(obj2));
                    keyStore.load(stream, password);
                }
                finally {
                    stream.close();
                }
            }
        }
        finally {
            if (password != null) {
                Arrays.fill(password, ' ');
            }
        }
    }
}
